# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cel/expr/conformance/proto2/test_all_types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cel/expr/conformance/proto2/test_all_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0cel/expr/conformance/proto2/test_all_types.proto\x12\x1b\x63\x65l.expr.conformance.proto2\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xc8\xfa\x01\n\x0cTestAllTypes\x12\x19\n\x0csingle_int32\x18\x01 \x01(\x05:\x03-32\x12\x19\n\x0csingle_int64\x18\x02 \x01(\x03:\x03-64\x12\x19\n\rsingle_uint32\x18\x03 \x01(\r:\x02\x33\x32\x12\x19\n\rsingle_uint64\x18\x04 \x01(\x04:\x02\x36\x34\x12\x15\n\rsingle_sint32\x18\x05 \x01(\x11\x12\x15\n\rsingle_sint64\x18\x06 \x01(\x12\x12\x16\n\x0esingle_fixed32\x18\x07 \x01(\x07\x12\x16\n\x0esingle_fixed64\x18\x08 \x01(\x06\x12\x17\n\x0fsingle_sfixed32\x18\t \x01(\x0f\x12\x17\n\x0fsingle_sfixed64\x18\n \x01(\x10\x12\x17\n\x0csingle_float\x18\x0b \x01(\x02:\x01\x33\x12\x1a\n\rsingle_double\x18\x0c \x01(\x01:\x03\x36.4\x12\x19\n\x0bsingle_bool\x18\r \x01(\x08:\x04true\x12\x1c\n\rsingle_string\x18\x0e \x01(\t:\x05\x65mpty\x12\x1a\n\x0csingle_bytes\x18\x0f \x01(\x0c:\x04none\x12\n\n\x02in\x18\x12 \x01(\x08\x12(\n\nsingle_any\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x32\n\x0fsingle_duration\x18\x65 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x10single_timestamp\x18\x66 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\rsingle_struct\x18g \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0csingle_value\x18h \x01(\x0b\x32\x16.google.protobuf.Value\x12\x39\n\x14single_int64_wrapper\x18i \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14single_int32_wrapper\x18j \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12;\n\x15single_double_wrapper\x18k \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x39\n\x14single_float_wrapper\x18l \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12;\n\x15single_uint64_wrapper\x18m \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12;\n\x15single_uint32_wrapper\x18n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x15single_string_wrapper\x18o \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x13single_bool_wrapper\x18p \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14single_bytes_wrapper\x18q \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12.\n\nlist_value\x18r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12.\n\nnull_value\x18s \x01(\x0e\x32\x1a.google.protobuf.NullValue\x12\x37\n\x13optional_null_value\x18t \x01(\x0e\x32\x1a.google.protobuf.NullValue\x12.\n\nfield_mask\x18u \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12%\n\x05\x65mpty\x18v \x01(\x0b\x32\x16.google.protobuf.Empty\x12X\n\x15single_nested_message\x18\x15 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessageH\x00\x12W\n\x12single_nested_enum\x18\x16 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x03\x42\x41RH\x00\x12S\n\x12standalone_message\x18\x17 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage\x12M\n\x0fstandalone_enum\x18\x18 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum\x12\x16\n\x0erepeated_int32\x18\x1f \x03(\x05\x12\x16\n\x0erepeated_int64\x18  \x03(\x03\x12\x17\n\x0frepeated_uint32\x18! \x03(\r\x12\x17\n\x0frepeated_uint64\x18\" \x03(\x04\x12\x17\n\x0frepeated_sint32\x18# \x03(\x11\x12\x17\n\x0frepeated_sint64\x18$ \x03(\x12\x12\x18\n\x10repeated_fixed32\x18% \x03(\x07\x12\x18\n\x10repeated_fixed64\x18& \x03(\x06\x12\x19\n\x11repeated_sfixed32\x18\' \x03(\x0f\x12\x19\n\x11repeated_sfixed64\x18( \x03(\x10\x12\x16\n\x0erepeated_float\x18) \x03(\x02\x12\x17\n\x0frepeated_double\x18* \x03(\x01\x12\x15\n\rrepeated_bool\x18+ \x03(\x08\x12\x17\n\x0frepeated_string\x18, \x03(\t\x12\x16\n\x0erepeated_bytes\x18- \x03(\x0c\x12X\n\x17repeated_nested_message\x18\x33 \x03(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage\x12R\n\x14repeated_nested_enum\x18\x34 \x03(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum\x12!\n\x15repeated_string_piece\x18\x35 \x03(\tB\x02\x08\x02\x12\x19\n\rrepeated_cord\x18\x36 \x03(\tB\x02\x08\x01\x12V\n\x15repeated_lazy_message\x18\x37 \x03(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage\x12*\n\x0crepeated_any\x18x \x03(\x0b\x32\x14.google.protobuf.Any\x12\x34\n\x11repeated_duration\x18y \x03(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x12repeated_timestamp\x18z \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0frepeated_struct\x18{ \x03(\x0b\x32\x17.google.protobuf.Struct\x12.\n\x0erepeated_value\x18| \x03(\x0b\x32\x16.google.protobuf.Value\x12;\n\x16repeated_int64_wrapper\x18} \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16repeated_int32_wrapper\x18~ \x03(\x0b\x32\x1b.google.protobuf.Int32Value\x12=\n\x17repeated_double_wrapper\x18\x7f \x03(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x16repeated_float_wrapper\x18\x80\x01 \x03(\x0b\x32\x1b.google.protobuf.FloatValue\x12>\n\x17repeated_uint64_wrapper\x18\x81\x01 \x03(\x0b\x32\x1c.google.protobuf.UInt64Value\x12>\n\x17repeated_uint32_wrapper\x18\x82\x01 \x03(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x17repeated_string_wrapper\x18\x83\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x15repeated_bool_wrapper\x18\x84\x01 \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16repeated_bytes_wrapper\x18\x85\x01 \x03(\x0b\x32\x1b.google.protobuf.BytesValue\x12\x38\n\x13repeated_list_value\x18\x86\x01 \x03(\x0b\x32\x1a.google.protobuf.ListValue\x12\x38\n\x13repeated_null_value\x18\x87\x01 \x03(\x0e\x32\x1a.google.protobuf.NullValue\x12`\n\x15map_int64_nested_type\x18> \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapInt64NestedTypeEntry\x12Q\n\rmap_bool_bool\x18? \x03(\x0b\x32:.cel.expr.conformance.proto2.TestAllTypes.MapBoolBoolEntry\x12U\n\x0fmap_bool_string\x18@ \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapBoolStringEntry\x12S\n\x0emap_bool_bytes\x18\x41 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapBoolBytesEntry\x12S\n\x0emap_bool_int32\x18\x42 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapBoolInt32Entry\x12S\n\x0emap_bool_int64\x18\x43 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapBoolInt64Entry\x12U\n\x0fmap_bool_uint32\x18\x44 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapBoolUint32Entry\x12U\n\x0fmap_bool_uint64\x18\x45 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapBoolUint64Entry\x12S\n\x0emap_bool_float\x18\x46 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapBoolFloatEntry\x12U\n\x0fmap_bool_double\x18G \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapBoolDoubleEntry\x12Q\n\rmap_bool_enum\x18H \x03(\x0b\x32:.cel.expr.conformance.proto2.TestAllTypes.MapBoolEnumEntry\x12W\n\x10map_bool_message\x18I \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapBoolMessageEntry\x12Z\n\x11map_bool_duration\x18\xe4\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapBoolDurationEntry\x12\\\n\x12map_bool_timestamp\x18\xe5\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapBoolTimestampEntry\x12]\n\x13map_bool_null_value\x18\xe6\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapBoolNullValueEntry\x12P\n\x0cmap_bool_any\x18\xf6\x01 \x03(\x0b\x32\x39.cel.expr.conformance.proto2.TestAllTypes.MapBoolAnyEntry\x12V\n\x0fmap_bool_struct\x18\xf7\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapBoolStructEntry\x12T\n\x0emap_bool_value\x18\xf8\x01 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapBoolValueEntry\x12]\n\x13map_bool_list_value\x18\xf9\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapBoolListValueEntry\x12\x63\n\x16map_bool_int64_wrapper\x18\xfa\x01 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapBoolInt64WrapperEntry\x12\x63\n\x16map_bool_int32_wrapper\x18\xfb\x01 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapBoolInt32WrapperEntry\x12\x65\n\x17map_bool_double_wrapper\x18\xfc\x01 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapBoolDoubleWrapperEntry\x12\x63\n\x16map_bool_float_wrapper\x18\xfd\x01 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapBoolFloatWrapperEntry\x12\x65\n\x17map_bool_uint64_wrapper\x18\xfe\x01 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapBoolUint64WrapperEntry\x12\x65\n\x17map_bool_uint32_wrapper\x18\xff\x01 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapBoolUint32WrapperEntry\x12\x65\n\x17map_bool_string_wrapper\x18\x80\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapBoolStringWrapperEntry\x12\x61\n\x15map_bool_bool_wrapper\x18\x81\x02 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapBoolBoolWrapperEntry\x12\x63\n\x16map_bool_bytes_wrapper\x18\x82\x02 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapBoolBytesWrapperEntry\x12S\n\x0emap_int32_bool\x18J \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapInt32BoolEntry\x12W\n\x10map_int32_string\x18K \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt32StringEntry\x12U\n\x0fmap_int32_bytes\x18L \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt32BytesEntry\x12U\n\x0fmap_int32_int32\x18M \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt32Int32Entry\x12U\n\x0fmap_int32_int64\x18N \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt32Int64Entry\x12W\n\x10map_int32_uint32\x18O \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt32Uint32Entry\x12W\n\x10map_int32_uint64\x18P \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt32Uint64Entry\x12U\n\x0fmap_int32_float\x18Q \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt32FloatEntry\x12W\n\x10map_int32_double\x18R \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt32DoubleEntry\x12S\n\x0emap_int32_enum\x18S \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapInt32EnumEntry\x12Y\n\x11map_int32_message\x18T \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapInt32MessageEntry\x12\\\n\x12map_int32_duration\x18\xe7\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapInt32DurationEntry\x12^\n\x13map_int32_timestamp\x18\xe8\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt32TimestampEntry\x12_\n\x14map_int32_null_value\x18\xe9\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt32NullValueEntry\x12R\n\rmap_int32_any\x18\x83\x02 \x03(\x0b\x32:.cel.expr.conformance.proto2.TestAllTypes.MapInt32AnyEntry\x12X\n\x10map_int32_struct\x18\x84\x02 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt32StructEntry\x12V\n\x0fmap_int32_value\x18\x85\x02 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt32ValueEntry\x12_\n\x14map_int32_list_value\x18\x86\x02 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt32ListValueEntry\x12\x65\n\x17map_int32_int64_wrapper\x18\x87\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt32Int64WrapperEntry\x12\x65\n\x17map_int32_int32_wrapper\x18\x88\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt32Int32WrapperEntry\x12g\n\x18map_int32_double_wrapper\x18\x89\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt32DoubleWrapperEntry\x12\x65\n\x17map_int32_float_wrapper\x18\x8a\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt32FloatWrapperEntry\x12g\n\x18map_int32_uint64_wrapper\x18\x8b\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt32Uint64WrapperEntry\x12g\n\x18map_int32_uint32_wrapper\x18\x8c\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt32Uint32WrapperEntry\x12g\n\x18map_int32_string_wrapper\x18\x8d\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt32StringWrapperEntry\x12\x63\n\x16map_int32_bool_wrapper\x18\x8e\x02 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapInt32BoolWrapperEntry\x12\x65\n\x17map_int32_bytes_wrapper\x18\x8f\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt32BytesWrapperEntry\x12S\n\x0emap_int64_bool\x18U \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapInt64BoolEntry\x12W\n\x10map_int64_string\x18V \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt64StringEntry\x12U\n\x0fmap_int64_bytes\x18W \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt64BytesEntry\x12U\n\x0fmap_int64_int32\x18X \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt64Int32Entry\x12U\n\x0fmap_int64_int64\x18Y \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt64Int64Entry\x12W\n\x10map_int64_uint32\x18Z \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt64Uint32Entry\x12W\n\x10map_int64_uint64\x18[ \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt64Uint64Entry\x12U\n\x0fmap_int64_float\x18\\ \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt64FloatEntry\x12W\n\x10map_int64_double\x18] \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt64DoubleEntry\x12S\n\x0emap_int64_enum\x18^ \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapInt64EnumEntry\x12Y\n\x11map_int64_message\x18_ \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapInt64MessageEntry\x12\\\n\x12map_int64_duration\x18\xea\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapInt64DurationEntry\x12^\n\x13map_int64_timestamp\x18\xeb\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt64TimestampEntry\x12_\n\x14map_int64_null_value\x18\xec\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt64NullValueEntry\x12R\n\rmap_int64_any\x18\x90\x02 \x03(\x0b\x32:.cel.expr.conformance.proto2.TestAllTypes.MapInt64AnyEntry\x12X\n\x10map_int64_struct\x18\x91\x02 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapInt64StructEntry\x12V\n\x0fmap_int64_value\x18\x92\x02 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapInt64ValueEntry\x12_\n\x14map_int64_list_value\x18\x93\x02 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapInt64ListValueEntry\x12\x65\n\x17map_int64_int64_wrapper\x18\x94\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt64Int64WrapperEntry\x12\x65\n\x17map_int64_int32_wrapper\x18\x95\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt64Int32WrapperEntry\x12g\n\x18map_int64_double_wrapper\x18\x96\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt64DoubleWrapperEntry\x12\x65\n\x17map_int64_float_wrapper\x18\x97\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt64FloatWrapperEntry\x12g\n\x18map_int64_uint64_wrapper\x18\x98\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt64Uint64WrapperEntry\x12g\n\x18map_int64_uint32_wrapper\x18\x99\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt64Uint32WrapperEntry\x12g\n\x18map_int64_string_wrapper\x18\x9a\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapInt64StringWrapperEntry\x12\x63\n\x16map_int64_bool_wrapper\x18\x9b\x02 \x03(\x0b\x32\x42.cel.expr.conformance.proto2.TestAllTypes.MapInt64BoolWrapperEntry\x12\x65\n\x17map_int64_bytes_wrapper\x18\x9c\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapInt64BytesWrapperEntry\x12U\n\x0fmap_uint32_bool\x18` \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapUint32BoolEntry\x12Y\n\x11map_uint32_string\x18\x61 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint32StringEntry\x12W\n\x10map_uint32_bytes\x18\x62 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint32BytesEntry\x12W\n\x10map_uint32_int32\x18\x63 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint32Int32Entry\x12X\n\x10map_uint32_int64\x18\xc8\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint32Int64Entry\x12Z\n\x11map_uint32_uint32\x18\xc9\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint32Uint32Entry\x12Z\n\x11map_uint32_uint64\x18\xca\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint32Uint64Entry\x12X\n\x10map_uint32_float\x18\xcb\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint32FloatEntry\x12Z\n\x11map_uint32_double\x18\xcc\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint32DoubleEntry\x12V\n\x0fmap_uint32_enum\x18\xcd\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapUint32EnumEntry\x12\\\n\x12map_uint32_message\x18\xce\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapUint32MessageEntry\x12^\n\x13map_uint32_duration\x18\xed\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapUint32DurationEntry\x12`\n\x14map_uint32_timestamp\x18\xee\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint32TimestampEntry\x12\x61\n\x15map_uint32_null_value\x18\xef\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint32NullValueEntry\x12T\n\x0emap_uint32_any\x18\x9d\x02 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapUint32AnyEntry\x12Z\n\x11map_uint32_struct\x18\x9e\x02 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint32StructEntry\x12X\n\x10map_uint32_value\x18\x9f\x02 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint32ValueEntry\x12\x61\n\x15map_uint32_list_value\x18\xa0\x02 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint32ListValueEntry\x12g\n\x18map_uint32_int64_wrapper\x18\xa1\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint32Int64WrapperEntry\x12g\n\x18map_uint32_int32_wrapper\x18\xa2\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint32Int32WrapperEntry\x12i\n\x19map_uint32_double_wrapper\x18\xa3\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint32DoubleWrapperEntry\x12g\n\x18map_uint32_float_wrapper\x18\xa4\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint32FloatWrapperEntry\x12i\n\x19map_uint32_uint64_wrapper\x18\xa5\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint32Uint64WrapperEntry\x12i\n\x19map_uint32_uint32_wrapper\x18\xa6\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint32Uint32WrapperEntry\x12i\n\x19map_uint32_string_wrapper\x18\xa7\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint32StringWrapperEntry\x12\x65\n\x17map_uint32_bool_wrapper\x18\xa8\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapUint32BoolWrapperEntry\x12g\n\x18map_uint32_bytes_wrapper\x18\xa9\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint32BytesWrapperEntry\x12V\n\x0fmap_uint64_bool\x18\xcf\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapUint64BoolEntry\x12Z\n\x11map_uint64_string\x18\xd0\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint64StringEntry\x12X\n\x10map_uint64_bytes\x18\xd1\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint64BytesEntry\x12X\n\x10map_uint64_int32\x18\xd2\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint64Int32Entry\x12X\n\x10map_uint64_int64\x18\xd3\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint64Int64Entry\x12Z\n\x11map_uint64_uint32\x18\xd4\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint64Uint32Entry\x12Z\n\x11map_uint64_uint64\x18\xd5\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint64Uint64Entry\x12X\n\x10map_uint64_float\x18\xd6\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint64FloatEntry\x12Z\n\x11map_uint64_double\x18\xd7\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint64DoubleEntry\x12V\n\x0fmap_uint64_enum\x18\xd8\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapUint64EnumEntry\x12\\\n\x12map_uint64_message\x18\xd9\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapUint64MessageEntry\x12^\n\x13map_uint64_duration\x18\xf0\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapUint64DurationEntry\x12`\n\x14map_uint64_timestamp\x18\xf1\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint64TimestampEntry\x12\x61\n\x15map_uint64_null_value\x18\xf2\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint64NullValueEntry\x12T\n\x0emap_uint64_any\x18\xaa\x02 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapUint64AnyEntry\x12Z\n\x11map_uint64_struct\x18\xab\x02 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapUint64StructEntry\x12X\n\x10map_uint64_value\x18\xac\x02 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapUint64ValueEntry\x12\x61\n\x15map_uint64_list_value\x18\xad\x02 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapUint64ListValueEntry\x12g\n\x18map_uint64_int64_wrapper\x18\xae\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint64Int64WrapperEntry\x12g\n\x18map_uint64_int32_wrapper\x18\xaf\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint64Int32WrapperEntry\x12i\n\x19map_uint64_double_wrapper\x18\xb0\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint64DoubleWrapperEntry\x12g\n\x18map_uint64_float_wrapper\x18\xb1\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint64FloatWrapperEntry\x12i\n\x19map_uint64_uint64_wrapper\x18\xb2\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint64Uint64WrapperEntry\x12i\n\x19map_uint64_uint32_wrapper\x18\xb3\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint64Uint32WrapperEntry\x12i\n\x19map_uint64_string_wrapper\x18\xb4\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapUint64StringWrapperEntry\x12\x65\n\x17map_uint64_bool_wrapper\x18\xb5\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapUint64BoolWrapperEntry\x12g\n\x18map_uint64_bytes_wrapper\x18\xb6\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapUint64BytesWrapperEntry\x12V\n\x0fmap_string_bool\x18\xda\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapStringBoolEntry\x12Y\n\x11map_string_string\x18= \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapStringStringEntry\x12X\n\x10map_string_bytes\x18\xdb\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapStringBytesEntry\x12X\n\x10map_string_int32\x18\xdc\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapStringInt32Entry\x12X\n\x10map_string_int64\x18\xdd\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapStringInt64Entry\x12Z\n\x11map_string_uint32\x18\xde\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapStringUint32Entry\x12Z\n\x11map_string_uint64\x18\xdf\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapStringUint64Entry\x12X\n\x10map_string_float\x18\xe0\x01 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapStringFloatEntry\x12Z\n\x11map_string_double\x18\xe1\x01 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapStringDoubleEntry\x12V\n\x0fmap_string_enum\x18\xe2\x01 \x03(\x0b\x32<.cel.expr.conformance.proto2.TestAllTypes.MapStringEnumEntry\x12\\\n\x12map_string_message\x18\xe3\x01 \x03(\x0b\x32?.cel.expr.conformance.proto2.TestAllTypes.MapStringMessageEntry\x12^\n\x13map_string_duration\x18\xf3\x01 \x03(\x0b\x32@.cel.expr.conformance.proto2.TestAllTypes.MapStringDurationEntry\x12`\n\x14map_string_timestamp\x18\xf4\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapStringTimestampEntry\x12\x61\n\x15map_string_null_value\x18\xf5\x01 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapStringNullValueEntry\x12T\n\x0emap_string_any\x18\xb7\x02 \x03(\x0b\x32;.cel.expr.conformance.proto2.TestAllTypes.MapStringAnyEntry\x12Z\n\x11map_string_struct\x18\xb8\x02 \x03(\x0b\x32>.cel.expr.conformance.proto2.TestAllTypes.MapStringStructEntry\x12X\n\x10map_string_value\x18\xb9\x02 \x03(\x0b\x32=.cel.expr.conformance.proto2.TestAllTypes.MapStringValueEntry\x12\x61\n\x15map_string_list_value\x18\xba\x02 \x03(\x0b\x32\x41.cel.expr.conformance.proto2.TestAllTypes.MapStringListValueEntry\x12g\n\x18map_string_int64_wrapper\x18\xbb\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapStringInt64WrapperEntry\x12g\n\x18map_string_int32_wrapper\x18\xbc\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapStringInt32WrapperEntry\x12i\n\x19map_string_double_wrapper\x18\xbd\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapStringDoubleWrapperEntry\x12g\n\x18map_string_float_wrapper\x18\xbe\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapStringFloatWrapperEntry\x12i\n\x19map_string_uint64_wrapper\x18\xbf\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapStringUint64WrapperEntry\x12i\n\x19map_string_uint32_wrapper\x18\xc0\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapStringUint32WrapperEntry\x12i\n\x19map_string_string_wrapper\x18\xc1\x02 \x03(\x0b\x32\x45.cel.expr.conformance.proto2.TestAllTypes.MapStringStringWrapperEntry\x12\x65\n\x17map_string_bool_wrapper\x18\xc2\x02 \x03(\x0b\x32\x43.cel.expr.conformance.proto2.TestAllTypes.MapStringBoolWrapperEntry\x12g\n\x18map_string_bytes_wrapper\x18\xc3\x02 \x03(\x0b\x32\x44.cel.expr.conformance.proto2.TestAllTypes.MapStringBytesWrapperEntry\x12\x46\n\noneof_type\x18\x90\x03 \x01(\x0b\x32/.cel.expr.conformance.proto2.NestedTestAllTypesH\x01\x12M\n\toneof_msg\x18\x91\x03 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessageH\x01\x12\x15\n\noneof_bool\x18\x92\x03 \x01(\x08H\x01\x12K\n\x0bnestedgroup\x18\x93\x03 \x01(\n25.cel.expr.conformance.proto2.TestAllTypes.NestedGroup\x1a\x1b\n\rNestedMessage\x12\n\n\x02\x62\x62\x18\x01 \x01(\x05\x1aj\n\x17MapInt64NestedTypeEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.cel.expr.conformance.proto2.NestedTestAllTypes:\x02\x38\x01\x1a\x32\n\x10MapBoolBoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x34\n\x12MapBoolStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11MapBoolBytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x33\n\x11MapBoolInt32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x33\n\x11MapBoolInt64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x34\n\x12MapBoolUint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x34\n\x12MapBoolUint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x33\n\x11MapBoolFloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x34\n\x12MapBoolDoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1ah\n\x10MapBoolEnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1an\n\x13MapBoolMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aQ\n\x14MapBoolDurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aS\n\x15MapBoolTimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aS\n\x15MapBoolNullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aG\n\x0fMapBoolAnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aM\n\x12MapBoolStructEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aK\n\x11MapBoolValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aS\n\x15MapBoolListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aW\n\x18MapBoolInt64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aW\n\x18MapBoolInt32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1aY\n\x19MapBoolDoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aW\n\x18MapBoolFloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1aY\n\x19MapBoolUint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1aY\n\x19MapBoolUint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1aY\n\x19MapBoolStringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aU\n\x17MapBoolBoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aW\n\x18MapBoolBytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x33\n\x11MapInt32BoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x35\n\x13MapInt32StringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12MapInt32BytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x34\n\x12MapInt32Int32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12MapInt32Int64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x35\n\x13MapInt32Uint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x35\n\x13MapInt32Uint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x34\n\x12MapInt32FloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x35\n\x13MapInt32DoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1ai\n\x11MapInt32EnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1ao\n\x14MapInt32MessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aR\n\x15MapInt32DurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aT\n\x16MapInt32TimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aT\n\x16MapInt32NullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aH\n\x10MapInt32AnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aN\n\x13MapInt32StructEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aL\n\x12MapInt32ValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aT\n\x16MapInt32ListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aX\n\x19MapInt32Int64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aX\n\x19MapInt32Int32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1aZ\n\x1aMapInt32DoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aX\n\x19MapInt32FloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1aZ\n\x1aMapInt32Uint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1aZ\n\x1aMapInt32Uint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1aZ\n\x1aMapInt32StringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aV\n\x18MapInt32BoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aX\n\x19MapInt32BytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x33\n\x11MapInt64BoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x35\n\x13MapInt64StringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12MapInt64BytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x34\n\x12MapInt64Int32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12MapInt64Int64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x35\n\x13MapInt64Uint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x35\n\x13MapInt64Uint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x34\n\x12MapInt64FloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x35\n\x13MapInt64DoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1ai\n\x11MapInt64EnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1ao\n\x14MapInt64MessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aR\n\x15MapInt64DurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aT\n\x16MapInt64TimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aT\n\x16MapInt64NullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aH\n\x10MapInt64AnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aN\n\x13MapInt64StructEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aL\n\x12MapInt64ValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aT\n\x16MapInt64ListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aX\n\x19MapInt64Int64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aX\n\x19MapInt64Int32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1aZ\n\x1aMapInt64DoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aX\n\x19MapInt64FloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1aZ\n\x1aMapInt64Uint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1aZ\n\x1aMapInt64Uint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1aZ\n\x1aMapInt64StringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aV\n\x18MapInt64BoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aX\n\x19MapInt64BytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x34\n\x12MapUint32BoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14MapUint32StringEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13MapUint32BytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x35\n\x13MapUint32Int32Entry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x35\n\x13MapUint32Int64Entry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x36\n\x14MapUint32Uint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x36\n\x14MapUint32Uint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x35\n\x13MapUint32FloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x36\n\x14MapUint32DoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1aj\n\x12MapUint32EnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1ap\n\x15MapUint32MessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aS\n\x16MapUint32DurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aU\n\x17MapUint32TimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aU\n\x17MapUint32NullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aI\n\x11MapUint32AnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aO\n\x14MapUint32StructEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aM\n\x13MapUint32ValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aU\n\x17MapUint32ListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aY\n\x1aMapUint32Int64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aY\n\x1aMapUint32Int32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1a[\n\x1bMapUint32DoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aY\n\x1aMapUint32FloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1a[\n\x1bMapUint32Uint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1a[\n\x1bMapUint32Uint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1a[\n\x1bMapUint32StringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aW\n\x19MapUint32BoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aY\n\x1aMapUint32BytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x34\n\x12MapUint64BoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14MapUint64StringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13MapUint64BytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x35\n\x13MapUint64Int32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x35\n\x13MapUint64Int64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x36\n\x14MapUint64Uint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x36\n\x14MapUint64Uint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x35\n\x13MapUint64FloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x36\n\x14MapUint64DoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1aj\n\x12MapUint64EnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1ap\n\x15MapUint64MessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aS\n\x16MapUint64DurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aU\n\x17MapUint64TimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aU\n\x17MapUint64NullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aI\n\x11MapUint64AnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aO\n\x14MapUint64StructEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aM\n\x13MapUint64ValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aU\n\x17MapUint64ListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aY\n\x1aMapUint64Int64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aY\n\x1aMapUint64Int32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1a[\n\x1bMapUint64DoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aY\n\x1aMapUint64FloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1a[\n\x1bMapUint64Uint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1a[\n\x1bMapUint64Uint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1a[\n\x1bMapUint64StringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aW\n\x19MapUint64BoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aY\n\x1aMapUint64BytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x34\n\x12MapStringBoolEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x36\n\x14MapStringStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13MapStringBytesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x35\n\x13MapStringInt32Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x35\n\x13MapStringInt64Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x36\n\x14MapStringUint32Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x36\n\x14MapStringUint64Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x35\n\x13MapStringFloatEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x36\n\x14MapStringDoubleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1aj\n\x12MapStringEnumEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0e\x32\x34.cel.expr.conformance.proto2.TestAllTypes.NestedEnum:\x02\x38\x01\x1ap\n\x15MapStringMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.cel.expr.conformance.proto2.TestAllTypes.NestedMessage:\x02\x38\x01\x1aS\n\x16MapStringDurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x38\x01\x1aU\n\x17MapStringTimestampEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aU\n\x17MapStringNullValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValue:\x02\x38\x01\x1aI\n\x11MapStringAnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1aO\n\x14MapStringStructEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aM\n\x13MapStringValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x1aU\n\x17MapStringListValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aY\n\x1aMapStringInt64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x02\x38\x01\x1aY\n\x1aMapStringInt32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value:\x02\x38\x01\x1a[\n\x1bMapStringDoubleWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x02\x38\x01\x1aY\n\x1aMapStringFloatWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\x1a[\n\x1bMapStringUint64WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value:\x02\x38\x01\x1a[\n\x1bMapStringUint32WrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:\x02\x38\x01\x1a[\n\x1bMapStringStringWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x02\x38\x01\x1aW\n\x19MapStringBoolWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:\x02\x38\x01\x1aY\n\x1aMapStringBytesWrapperEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x02\x38\x01\x1a\x37\n\x0bNestedGroup\x12\x12\n\tsingle_id\x18\x94\x03 \x01(\x05\x12\x14\n\x0bsingle_name\x18\x95\x03 \x01(\t\"\'\n\nNestedEnum\x12\x07\n\x03\x46OO\x10\x00\x12\x07\n\x03\x42\x41R\x10\x01\x12\x07\n\x03\x42\x41Z\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\x42\r\n\x0bnested_typeB\x06\n\x04kind\"\x90\x01\n\x12NestedTestAllTypes\x12>\n\x05\x63hild\x18\x01 \x01(\x0b\x32/.cel.expr.conformance.proto2.NestedTestAllTypes\x12:\n\x07payload\x18\x02 \x01(\x0b\x32).cel.expr.conformance.proto2.TestAllTypes\"&\n\x0cTestRequired\x12\x16\n\x0erequired_int32\x18\x01 \x02(\x05*\'\n\nGlobalEnum\x12\x07\n\x03GOO\x10\x00\x12\x07\n\x03GAR\x10\x01\x12\x07\n\x03GAZ\x10\x02\x42Z\n\x1f\x64\x65v.cel.expr.conformance.proto2B\x11TestAllTypesProtoP\x01Z\x1f\x63\x65l.dev/expr/conformance/proto2\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cel.expr.conformance.proto2.test_all_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037dev.cel.expr.conformance.proto2B\021TestAllTypesProtoP\001Z\037cel.dev/expr/conformance/proto2\370\001\001'
  _globals['_TESTALLTYPES_MAPINT64NESTEDTYPEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64NESTEDTYPEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLBOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLBOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLSTRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLSTRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLBYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLBYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLUINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLUINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLUINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLUINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLFLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLFLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLMESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLMESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLDURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLDURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLTIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLTIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLNULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLNULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLSTRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLSTRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLLISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLLISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLFLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLFLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLUINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLUINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLUINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLUINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLSTRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLSTRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLBOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLBOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPBOOLBYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPBOOLBYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32BOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32BOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32STRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32STRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32BYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32BYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32INT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32INT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32INT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32INT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32UINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32UINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32UINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32UINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32FLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32FLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32DOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32DOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32ENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32ENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32MESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32DURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32DURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32TIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32TIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32NULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32NULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32ANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32ANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32STRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32STRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32VALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32VALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32LISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32LISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32INT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32INT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32INT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32INT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32DOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32DOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32FLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32FLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32UINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32UINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32UINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32UINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32STRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32STRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32BOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32BOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT32BYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT32BYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64BOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64BOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64STRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64STRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64BYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64BYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64INT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64INT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64INT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64INT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64UINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64UINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64UINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64UINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64FLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64FLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64DOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64DOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64ENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64ENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64MESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64DURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64DURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64TIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64TIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64NULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64NULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64ANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64ANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64STRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64STRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64VALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64VALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64LISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64LISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64INT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64INT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64INT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64INT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64DOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64DOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64FLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64FLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64UINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64UINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64UINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64UINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64STRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64STRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64BOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64BOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPINT64BYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPINT64BYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32BOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32BOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32STRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32STRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32BYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32BYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32INT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32INT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32INT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32INT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32UINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32UINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32UINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32UINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32FLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32FLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32ENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32ENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32MESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32DURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32DURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32TIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32TIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32NULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32NULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32ANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32ANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32STRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32STRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32VALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32VALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32LISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32LISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32INT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32INT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32INT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32INT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32FLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32FLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32UINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32UINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32UINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32UINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32STRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32STRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32BOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32BOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT32BYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT32BYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64BOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64BOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64STRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64STRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64BYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64BYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64INT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64INT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64INT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64INT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64UINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64UINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64UINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64UINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64FLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64FLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64ENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64ENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64MESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64DURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64DURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64TIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64TIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64NULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64NULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64ANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64ANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64STRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64STRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64VALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64VALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64LISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64LISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64INT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64INT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64INT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64INT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64FLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64FLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64UINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64UINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64UINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64UINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64STRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64STRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64BOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64BOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPUINT64BYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPUINT64BYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGBOOLENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGBOOLENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGBYTESENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGBYTESENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGUINT32ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGUINT32ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGUINT64ENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGUINT64ENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGFLOATENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGFLOATENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGENUMENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGENUMENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGMESSAGEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGMESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGDURATIONENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGDURATIONENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGTIMESTAMPENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGTIMESTAMPENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGNULLVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGNULLVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGANYENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGANYENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGSTRUCTENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGSTRUCTENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGLISTVALUEENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGLISTVALUEENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGFLOATWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGFLOATWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGUINT64WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGUINT64WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGUINT32WRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGUINT32WRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGBOOLWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGBOOLWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES_MAPSTRINGBYTESWRAPPERENTRY']._loaded_options = None
  _globals['_TESTALLTYPES_MAPSTRINGBYTESWRAPPERENTRY']._serialized_options = b'8\001'
  _globals['_TESTALLTYPES'].fields_by_name['repeated_string_piece']._loaded_options = None
  _globals['_TESTALLTYPES'].fields_by_name['repeated_string_piece']._serialized_options = b'\010\002'
  _globals['_TESTALLTYPES'].fields_by_name['repeated_cord']._loaded_options = None
  _globals['_TESTALLTYPES'].fields_by_name['repeated_cord']._serialized_options = b'\010\001'
  _globals['_GLOBALENUM']._serialized_start=32561
  _globals['_GLOBALENUM']._serialized_end=32600
  _globals['_TESTALLTYPES']._serialized_start=300
  _globals['_TESTALLTYPES']._serialized_end=32372
  _globals['_TESTALLTYPES_NESTEDMESSAGE']._serialized_start=19457
  _globals['_TESTALLTYPES_NESTEDMESSAGE']._serialized_end=19484
  _globals['_TESTALLTYPES_MAPINT64NESTEDTYPEENTRY']._serialized_start=19486
  _globals['_TESTALLTYPES_MAPINT64NESTEDTYPEENTRY']._serialized_end=19592
  _globals['_TESTALLTYPES_MAPBOOLBOOLENTRY']._serialized_start=19594
  _globals['_TESTALLTYPES_MAPBOOLBOOLENTRY']._serialized_end=19644
  _globals['_TESTALLTYPES_MAPBOOLSTRINGENTRY']._serialized_start=19646
  _globals['_TESTALLTYPES_MAPBOOLSTRINGENTRY']._serialized_end=19698
  _globals['_TESTALLTYPES_MAPBOOLBYTESENTRY']._serialized_start=19700
  _globals['_TESTALLTYPES_MAPBOOLBYTESENTRY']._serialized_end=19751
  _globals['_TESTALLTYPES_MAPBOOLINT32ENTRY']._serialized_start=19753
  _globals['_TESTALLTYPES_MAPBOOLINT32ENTRY']._serialized_end=19804
  _globals['_TESTALLTYPES_MAPBOOLINT64ENTRY']._serialized_start=19806
  _globals['_TESTALLTYPES_MAPBOOLINT64ENTRY']._serialized_end=19857
  _globals['_TESTALLTYPES_MAPBOOLUINT32ENTRY']._serialized_start=19859
  _globals['_TESTALLTYPES_MAPBOOLUINT32ENTRY']._serialized_end=19911
  _globals['_TESTALLTYPES_MAPBOOLUINT64ENTRY']._serialized_start=19913
  _globals['_TESTALLTYPES_MAPBOOLUINT64ENTRY']._serialized_end=19965
  _globals['_TESTALLTYPES_MAPBOOLFLOATENTRY']._serialized_start=19967
  _globals['_TESTALLTYPES_MAPBOOLFLOATENTRY']._serialized_end=20018
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEENTRY']._serialized_start=20020
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEENTRY']._serialized_end=20072
  _globals['_TESTALLTYPES_MAPBOOLENUMENTRY']._serialized_start=20074
  _globals['_TESTALLTYPES_MAPBOOLENUMENTRY']._serialized_end=20178
  _globals['_TESTALLTYPES_MAPBOOLMESSAGEENTRY']._serialized_start=20180
  _globals['_TESTALLTYPES_MAPBOOLMESSAGEENTRY']._serialized_end=20290
  _globals['_TESTALLTYPES_MAPBOOLDURATIONENTRY']._serialized_start=20292
  _globals['_TESTALLTYPES_MAPBOOLDURATIONENTRY']._serialized_end=20373
  _globals['_TESTALLTYPES_MAPBOOLTIMESTAMPENTRY']._serialized_start=20375
  _globals['_TESTALLTYPES_MAPBOOLTIMESTAMPENTRY']._serialized_end=20458
  _globals['_TESTALLTYPES_MAPBOOLNULLVALUEENTRY']._serialized_start=20460
  _globals['_TESTALLTYPES_MAPBOOLNULLVALUEENTRY']._serialized_end=20543
  _globals['_TESTALLTYPES_MAPBOOLANYENTRY']._serialized_start=20545
  _globals['_TESTALLTYPES_MAPBOOLANYENTRY']._serialized_end=20616
  _globals['_TESTALLTYPES_MAPBOOLSTRUCTENTRY']._serialized_start=20618
  _globals['_TESTALLTYPES_MAPBOOLSTRUCTENTRY']._serialized_end=20695
  _globals['_TESTALLTYPES_MAPBOOLVALUEENTRY']._serialized_start=20697
  _globals['_TESTALLTYPES_MAPBOOLVALUEENTRY']._serialized_end=20772
  _globals['_TESTALLTYPES_MAPBOOLLISTVALUEENTRY']._serialized_start=20774
  _globals['_TESTALLTYPES_MAPBOOLLISTVALUEENTRY']._serialized_end=20857
  _globals['_TESTALLTYPES_MAPBOOLINT64WRAPPERENTRY']._serialized_start=20859
  _globals['_TESTALLTYPES_MAPBOOLINT64WRAPPERENTRY']._serialized_end=20946
  _globals['_TESTALLTYPES_MAPBOOLINT32WRAPPERENTRY']._serialized_start=20948
  _globals['_TESTALLTYPES_MAPBOOLINT32WRAPPERENTRY']._serialized_end=21035
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEWRAPPERENTRY']._serialized_start=21037
  _globals['_TESTALLTYPES_MAPBOOLDOUBLEWRAPPERENTRY']._serialized_end=21126
  _globals['_TESTALLTYPES_MAPBOOLFLOATWRAPPERENTRY']._serialized_start=21128
  _globals['_TESTALLTYPES_MAPBOOLFLOATWRAPPERENTRY']._serialized_end=21215
  _globals['_TESTALLTYPES_MAPBOOLUINT64WRAPPERENTRY']._serialized_start=21217
  _globals['_TESTALLTYPES_MAPBOOLUINT64WRAPPERENTRY']._serialized_end=21306
  _globals['_TESTALLTYPES_MAPBOOLUINT32WRAPPERENTRY']._serialized_start=21308
  _globals['_TESTALLTYPES_MAPBOOLUINT32WRAPPERENTRY']._serialized_end=21397
  _globals['_TESTALLTYPES_MAPBOOLSTRINGWRAPPERENTRY']._serialized_start=21399
  _globals['_TESTALLTYPES_MAPBOOLSTRINGWRAPPERENTRY']._serialized_end=21488
  _globals['_TESTALLTYPES_MAPBOOLBOOLWRAPPERENTRY']._serialized_start=21490
  _globals['_TESTALLTYPES_MAPBOOLBOOLWRAPPERENTRY']._serialized_end=21575
  _globals['_TESTALLTYPES_MAPBOOLBYTESWRAPPERENTRY']._serialized_start=21577
  _globals['_TESTALLTYPES_MAPBOOLBYTESWRAPPERENTRY']._serialized_end=21664
  _globals['_TESTALLTYPES_MAPINT32BOOLENTRY']._serialized_start=21666
  _globals['_TESTALLTYPES_MAPINT32BOOLENTRY']._serialized_end=21717
  _globals['_TESTALLTYPES_MAPINT32STRINGENTRY']._serialized_start=21719
  _globals['_TESTALLTYPES_MAPINT32STRINGENTRY']._serialized_end=21772
  _globals['_TESTALLTYPES_MAPINT32BYTESENTRY']._serialized_start=21774
  _globals['_TESTALLTYPES_MAPINT32BYTESENTRY']._serialized_end=21826
  _globals['_TESTALLTYPES_MAPINT32INT32ENTRY']._serialized_start=21828
  _globals['_TESTALLTYPES_MAPINT32INT32ENTRY']._serialized_end=21880
  _globals['_TESTALLTYPES_MAPINT32INT64ENTRY']._serialized_start=21882
  _globals['_TESTALLTYPES_MAPINT32INT64ENTRY']._serialized_end=21934
  _globals['_TESTALLTYPES_MAPINT32UINT32ENTRY']._serialized_start=21936
  _globals['_TESTALLTYPES_MAPINT32UINT32ENTRY']._serialized_end=21989
  _globals['_TESTALLTYPES_MAPINT32UINT64ENTRY']._serialized_start=21991
  _globals['_TESTALLTYPES_MAPINT32UINT64ENTRY']._serialized_end=22044
  _globals['_TESTALLTYPES_MAPINT32FLOATENTRY']._serialized_start=22046
  _globals['_TESTALLTYPES_MAPINT32FLOATENTRY']._serialized_end=22098
  _globals['_TESTALLTYPES_MAPINT32DOUBLEENTRY']._serialized_start=22100
  _globals['_TESTALLTYPES_MAPINT32DOUBLEENTRY']._serialized_end=22153
  _globals['_TESTALLTYPES_MAPINT32ENUMENTRY']._serialized_start=22155
  _globals['_TESTALLTYPES_MAPINT32ENUMENTRY']._serialized_end=22260
  _globals['_TESTALLTYPES_MAPINT32MESSAGEENTRY']._serialized_start=22262
  _globals['_TESTALLTYPES_MAPINT32MESSAGEENTRY']._serialized_end=22373
  _globals['_TESTALLTYPES_MAPINT32DURATIONENTRY']._serialized_start=22375
  _globals['_TESTALLTYPES_MAPINT32DURATIONENTRY']._serialized_end=22457
  _globals['_TESTALLTYPES_MAPINT32TIMESTAMPENTRY']._serialized_start=22459
  _globals['_TESTALLTYPES_MAPINT32TIMESTAMPENTRY']._serialized_end=22543
  _globals['_TESTALLTYPES_MAPINT32NULLVALUEENTRY']._serialized_start=22545
  _globals['_TESTALLTYPES_MAPINT32NULLVALUEENTRY']._serialized_end=22629
  _globals['_TESTALLTYPES_MAPINT32ANYENTRY']._serialized_start=22631
  _globals['_TESTALLTYPES_MAPINT32ANYENTRY']._serialized_end=22703
  _globals['_TESTALLTYPES_MAPINT32STRUCTENTRY']._serialized_start=22705
  _globals['_TESTALLTYPES_MAPINT32STRUCTENTRY']._serialized_end=22783
  _globals['_TESTALLTYPES_MAPINT32VALUEENTRY']._serialized_start=22785
  _globals['_TESTALLTYPES_MAPINT32VALUEENTRY']._serialized_end=22861
  _globals['_TESTALLTYPES_MAPINT32LISTVALUEENTRY']._serialized_start=22863
  _globals['_TESTALLTYPES_MAPINT32LISTVALUEENTRY']._serialized_end=22947
  _globals['_TESTALLTYPES_MAPINT32INT64WRAPPERENTRY']._serialized_start=22949
  _globals['_TESTALLTYPES_MAPINT32INT64WRAPPERENTRY']._serialized_end=23037
  _globals['_TESTALLTYPES_MAPINT32INT32WRAPPERENTRY']._serialized_start=23039
  _globals['_TESTALLTYPES_MAPINT32INT32WRAPPERENTRY']._serialized_end=23127
  _globals['_TESTALLTYPES_MAPINT32DOUBLEWRAPPERENTRY']._serialized_start=23129
  _globals['_TESTALLTYPES_MAPINT32DOUBLEWRAPPERENTRY']._serialized_end=23219
  _globals['_TESTALLTYPES_MAPINT32FLOATWRAPPERENTRY']._serialized_start=23221
  _globals['_TESTALLTYPES_MAPINT32FLOATWRAPPERENTRY']._serialized_end=23309
  _globals['_TESTALLTYPES_MAPINT32UINT64WRAPPERENTRY']._serialized_start=23311
  _globals['_TESTALLTYPES_MAPINT32UINT64WRAPPERENTRY']._serialized_end=23401
  _globals['_TESTALLTYPES_MAPINT32UINT32WRAPPERENTRY']._serialized_start=23403
  _globals['_TESTALLTYPES_MAPINT32UINT32WRAPPERENTRY']._serialized_end=23493
  _globals['_TESTALLTYPES_MAPINT32STRINGWRAPPERENTRY']._serialized_start=23495
  _globals['_TESTALLTYPES_MAPINT32STRINGWRAPPERENTRY']._serialized_end=23585
  _globals['_TESTALLTYPES_MAPINT32BOOLWRAPPERENTRY']._serialized_start=23587
  _globals['_TESTALLTYPES_MAPINT32BOOLWRAPPERENTRY']._serialized_end=23673
  _globals['_TESTALLTYPES_MAPINT32BYTESWRAPPERENTRY']._serialized_start=23675
  _globals['_TESTALLTYPES_MAPINT32BYTESWRAPPERENTRY']._serialized_end=23763
  _globals['_TESTALLTYPES_MAPINT64BOOLENTRY']._serialized_start=23765
  _globals['_TESTALLTYPES_MAPINT64BOOLENTRY']._serialized_end=23816
  _globals['_TESTALLTYPES_MAPINT64STRINGENTRY']._serialized_start=23818
  _globals['_TESTALLTYPES_MAPINT64STRINGENTRY']._serialized_end=23871
  _globals['_TESTALLTYPES_MAPINT64BYTESENTRY']._serialized_start=23873
  _globals['_TESTALLTYPES_MAPINT64BYTESENTRY']._serialized_end=23925
  _globals['_TESTALLTYPES_MAPINT64INT32ENTRY']._serialized_start=23927
  _globals['_TESTALLTYPES_MAPINT64INT32ENTRY']._serialized_end=23979
  _globals['_TESTALLTYPES_MAPINT64INT64ENTRY']._serialized_start=23981
  _globals['_TESTALLTYPES_MAPINT64INT64ENTRY']._serialized_end=24033
  _globals['_TESTALLTYPES_MAPINT64UINT32ENTRY']._serialized_start=24035
  _globals['_TESTALLTYPES_MAPINT64UINT32ENTRY']._serialized_end=24088
  _globals['_TESTALLTYPES_MAPINT64UINT64ENTRY']._serialized_start=24090
  _globals['_TESTALLTYPES_MAPINT64UINT64ENTRY']._serialized_end=24143
  _globals['_TESTALLTYPES_MAPINT64FLOATENTRY']._serialized_start=24145
  _globals['_TESTALLTYPES_MAPINT64FLOATENTRY']._serialized_end=24197
  _globals['_TESTALLTYPES_MAPINT64DOUBLEENTRY']._serialized_start=24199
  _globals['_TESTALLTYPES_MAPINT64DOUBLEENTRY']._serialized_end=24252
  _globals['_TESTALLTYPES_MAPINT64ENUMENTRY']._serialized_start=24254
  _globals['_TESTALLTYPES_MAPINT64ENUMENTRY']._serialized_end=24359
  _globals['_TESTALLTYPES_MAPINT64MESSAGEENTRY']._serialized_start=24361
  _globals['_TESTALLTYPES_MAPINT64MESSAGEENTRY']._serialized_end=24472
  _globals['_TESTALLTYPES_MAPINT64DURATIONENTRY']._serialized_start=24474
  _globals['_TESTALLTYPES_MAPINT64DURATIONENTRY']._serialized_end=24556
  _globals['_TESTALLTYPES_MAPINT64TIMESTAMPENTRY']._serialized_start=24558
  _globals['_TESTALLTYPES_MAPINT64TIMESTAMPENTRY']._serialized_end=24642
  _globals['_TESTALLTYPES_MAPINT64NULLVALUEENTRY']._serialized_start=24644
  _globals['_TESTALLTYPES_MAPINT64NULLVALUEENTRY']._serialized_end=24728
  _globals['_TESTALLTYPES_MAPINT64ANYENTRY']._serialized_start=24730
  _globals['_TESTALLTYPES_MAPINT64ANYENTRY']._serialized_end=24802
  _globals['_TESTALLTYPES_MAPINT64STRUCTENTRY']._serialized_start=24804
  _globals['_TESTALLTYPES_MAPINT64STRUCTENTRY']._serialized_end=24882
  _globals['_TESTALLTYPES_MAPINT64VALUEENTRY']._serialized_start=24884
  _globals['_TESTALLTYPES_MAPINT64VALUEENTRY']._serialized_end=24960
  _globals['_TESTALLTYPES_MAPINT64LISTVALUEENTRY']._serialized_start=24962
  _globals['_TESTALLTYPES_MAPINT64LISTVALUEENTRY']._serialized_end=25046
  _globals['_TESTALLTYPES_MAPINT64INT64WRAPPERENTRY']._serialized_start=25048
  _globals['_TESTALLTYPES_MAPINT64INT64WRAPPERENTRY']._serialized_end=25136
  _globals['_TESTALLTYPES_MAPINT64INT32WRAPPERENTRY']._serialized_start=25138
  _globals['_TESTALLTYPES_MAPINT64INT32WRAPPERENTRY']._serialized_end=25226
  _globals['_TESTALLTYPES_MAPINT64DOUBLEWRAPPERENTRY']._serialized_start=25228
  _globals['_TESTALLTYPES_MAPINT64DOUBLEWRAPPERENTRY']._serialized_end=25318
  _globals['_TESTALLTYPES_MAPINT64FLOATWRAPPERENTRY']._serialized_start=25320
  _globals['_TESTALLTYPES_MAPINT64FLOATWRAPPERENTRY']._serialized_end=25408
  _globals['_TESTALLTYPES_MAPINT64UINT64WRAPPERENTRY']._serialized_start=25410
  _globals['_TESTALLTYPES_MAPINT64UINT64WRAPPERENTRY']._serialized_end=25500
  _globals['_TESTALLTYPES_MAPINT64UINT32WRAPPERENTRY']._serialized_start=25502
  _globals['_TESTALLTYPES_MAPINT64UINT32WRAPPERENTRY']._serialized_end=25592
  _globals['_TESTALLTYPES_MAPINT64STRINGWRAPPERENTRY']._serialized_start=25594
  _globals['_TESTALLTYPES_MAPINT64STRINGWRAPPERENTRY']._serialized_end=25684
  _globals['_TESTALLTYPES_MAPINT64BOOLWRAPPERENTRY']._serialized_start=25686
  _globals['_TESTALLTYPES_MAPINT64BOOLWRAPPERENTRY']._serialized_end=25772
  _globals['_TESTALLTYPES_MAPINT64BYTESWRAPPERENTRY']._serialized_start=25774
  _globals['_TESTALLTYPES_MAPINT64BYTESWRAPPERENTRY']._serialized_end=25862
  _globals['_TESTALLTYPES_MAPUINT32BOOLENTRY']._serialized_start=25864
  _globals['_TESTALLTYPES_MAPUINT32BOOLENTRY']._serialized_end=25916
  _globals['_TESTALLTYPES_MAPUINT32STRINGENTRY']._serialized_start=25918
  _globals['_TESTALLTYPES_MAPUINT32STRINGENTRY']._serialized_end=25972
  _globals['_TESTALLTYPES_MAPUINT32BYTESENTRY']._serialized_start=25974
  _globals['_TESTALLTYPES_MAPUINT32BYTESENTRY']._serialized_end=26027
  _globals['_TESTALLTYPES_MAPUINT32INT32ENTRY']._serialized_start=26029
  _globals['_TESTALLTYPES_MAPUINT32INT32ENTRY']._serialized_end=26082
  _globals['_TESTALLTYPES_MAPUINT32INT64ENTRY']._serialized_start=26084
  _globals['_TESTALLTYPES_MAPUINT32INT64ENTRY']._serialized_end=26137
  _globals['_TESTALLTYPES_MAPUINT32UINT32ENTRY']._serialized_start=26139
  _globals['_TESTALLTYPES_MAPUINT32UINT32ENTRY']._serialized_end=26193
  _globals['_TESTALLTYPES_MAPUINT32UINT64ENTRY']._serialized_start=26195
  _globals['_TESTALLTYPES_MAPUINT32UINT64ENTRY']._serialized_end=26249
  _globals['_TESTALLTYPES_MAPUINT32FLOATENTRY']._serialized_start=26251
  _globals['_TESTALLTYPES_MAPUINT32FLOATENTRY']._serialized_end=26304
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEENTRY']._serialized_start=26306
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEENTRY']._serialized_end=26360
  _globals['_TESTALLTYPES_MAPUINT32ENUMENTRY']._serialized_start=26362
  _globals['_TESTALLTYPES_MAPUINT32ENUMENTRY']._serialized_end=26468
  _globals['_TESTALLTYPES_MAPUINT32MESSAGEENTRY']._serialized_start=26470
  _globals['_TESTALLTYPES_MAPUINT32MESSAGEENTRY']._serialized_end=26582
  _globals['_TESTALLTYPES_MAPUINT32DURATIONENTRY']._serialized_start=26584
  _globals['_TESTALLTYPES_MAPUINT32DURATIONENTRY']._serialized_end=26667
  _globals['_TESTALLTYPES_MAPUINT32TIMESTAMPENTRY']._serialized_start=26669
  _globals['_TESTALLTYPES_MAPUINT32TIMESTAMPENTRY']._serialized_end=26754
  _globals['_TESTALLTYPES_MAPUINT32NULLVALUEENTRY']._serialized_start=26756
  _globals['_TESTALLTYPES_MAPUINT32NULLVALUEENTRY']._serialized_end=26841
  _globals['_TESTALLTYPES_MAPUINT32ANYENTRY']._serialized_start=26843
  _globals['_TESTALLTYPES_MAPUINT32ANYENTRY']._serialized_end=26916
  _globals['_TESTALLTYPES_MAPUINT32STRUCTENTRY']._serialized_start=26918
  _globals['_TESTALLTYPES_MAPUINT32STRUCTENTRY']._serialized_end=26997
  _globals['_TESTALLTYPES_MAPUINT32VALUEENTRY']._serialized_start=26999
  _globals['_TESTALLTYPES_MAPUINT32VALUEENTRY']._serialized_end=27076
  _globals['_TESTALLTYPES_MAPUINT32LISTVALUEENTRY']._serialized_start=27078
  _globals['_TESTALLTYPES_MAPUINT32LISTVALUEENTRY']._serialized_end=27163
  _globals['_TESTALLTYPES_MAPUINT32INT64WRAPPERENTRY']._serialized_start=27165
  _globals['_TESTALLTYPES_MAPUINT32INT64WRAPPERENTRY']._serialized_end=27254
  _globals['_TESTALLTYPES_MAPUINT32INT32WRAPPERENTRY']._serialized_start=27256
  _globals['_TESTALLTYPES_MAPUINT32INT32WRAPPERENTRY']._serialized_end=27345
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEWRAPPERENTRY']._serialized_start=27347
  _globals['_TESTALLTYPES_MAPUINT32DOUBLEWRAPPERENTRY']._serialized_end=27438
  _globals['_TESTALLTYPES_MAPUINT32FLOATWRAPPERENTRY']._serialized_start=27440
  _globals['_TESTALLTYPES_MAPUINT32FLOATWRAPPERENTRY']._serialized_end=27529
  _globals['_TESTALLTYPES_MAPUINT32UINT64WRAPPERENTRY']._serialized_start=27531
  _globals['_TESTALLTYPES_MAPUINT32UINT64WRAPPERENTRY']._serialized_end=27622
  _globals['_TESTALLTYPES_MAPUINT32UINT32WRAPPERENTRY']._serialized_start=27624
  _globals['_TESTALLTYPES_MAPUINT32UINT32WRAPPERENTRY']._serialized_end=27715
  _globals['_TESTALLTYPES_MAPUINT32STRINGWRAPPERENTRY']._serialized_start=27717
  _globals['_TESTALLTYPES_MAPUINT32STRINGWRAPPERENTRY']._serialized_end=27808
  _globals['_TESTALLTYPES_MAPUINT32BOOLWRAPPERENTRY']._serialized_start=27810
  _globals['_TESTALLTYPES_MAPUINT32BOOLWRAPPERENTRY']._serialized_end=27897
  _globals['_TESTALLTYPES_MAPUINT32BYTESWRAPPERENTRY']._serialized_start=27899
  _globals['_TESTALLTYPES_MAPUINT32BYTESWRAPPERENTRY']._serialized_end=27988
  _globals['_TESTALLTYPES_MAPUINT64BOOLENTRY']._serialized_start=27990
  _globals['_TESTALLTYPES_MAPUINT64BOOLENTRY']._serialized_end=28042
  _globals['_TESTALLTYPES_MAPUINT64STRINGENTRY']._serialized_start=28044
  _globals['_TESTALLTYPES_MAPUINT64STRINGENTRY']._serialized_end=28098
  _globals['_TESTALLTYPES_MAPUINT64BYTESENTRY']._serialized_start=28100
  _globals['_TESTALLTYPES_MAPUINT64BYTESENTRY']._serialized_end=28153
  _globals['_TESTALLTYPES_MAPUINT64INT32ENTRY']._serialized_start=28155
  _globals['_TESTALLTYPES_MAPUINT64INT32ENTRY']._serialized_end=28208
  _globals['_TESTALLTYPES_MAPUINT64INT64ENTRY']._serialized_start=28210
  _globals['_TESTALLTYPES_MAPUINT64INT64ENTRY']._serialized_end=28263
  _globals['_TESTALLTYPES_MAPUINT64UINT32ENTRY']._serialized_start=28265
  _globals['_TESTALLTYPES_MAPUINT64UINT32ENTRY']._serialized_end=28319
  _globals['_TESTALLTYPES_MAPUINT64UINT64ENTRY']._serialized_start=28321
  _globals['_TESTALLTYPES_MAPUINT64UINT64ENTRY']._serialized_end=28375
  _globals['_TESTALLTYPES_MAPUINT64FLOATENTRY']._serialized_start=28377
  _globals['_TESTALLTYPES_MAPUINT64FLOATENTRY']._serialized_end=28430
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEENTRY']._serialized_start=28432
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEENTRY']._serialized_end=28486
  _globals['_TESTALLTYPES_MAPUINT64ENUMENTRY']._serialized_start=28488
  _globals['_TESTALLTYPES_MAPUINT64ENUMENTRY']._serialized_end=28594
  _globals['_TESTALLTYPES_MAPUINT64MESSAGEENTRY']._serialized_start=28596
  _globals['_TESTALLTYPES_MAPUINT64MESSAGEENTRY']._serialized_end=28708
  _globals['_TESTALLTYPES_MAPUINT64DURATIONENTRY']._serialized_start=28710
  _globals['_TESTALLTYPES_MAPUINT64DURATIONENTRY']._serialized_end=28793
  _globals['_TESTALLTYPES_MAPUINT64TIMESTAMPENTRY']._serialized_start=28795
  _globals['_TESTALLTYPES_MAPUINT64TIMESTAMPENTRY']._serialized_end=28880
  _globals['_TESTALLTYPES_MAPUINT64NULLVALUEENTRY']._serialized_start=28882
  _globals['_TESTALLTYPES_MAPUINT64NULLVALUEENTRY']._serialized_end=28967
  _globals['_TESTALLTYPES_MAPUINT64ANYENTRY']._serialized_start=28969
  _globals['_TESTALLTYPES_MAPUINT64ANYENTRY']._serialized_end=29042
  _globals['_TESTALLTYPES_MAPUINT64STRUCTENTRY']._serialized_start=29044
  _globals['_TESTALLTYPES_MAPUINT64STRUCTENTRY']._serialized_end=29123
  _globals['_TESTALLTYPES_MAPUINT64VALUEENTRY']._serialized_start=29125
  _globals['_TESTALLTYPES_MAPUINT64VALUEENTRY']._serialized_end=29202
  _globals['_TESTALLTYPES_MAPUINT64LISTVALUEENTRY']._serialized_start=29204
  _globals['_TESTALLTYPES_MAPUINT64LISTVALUEENTRY']._serialized_end=29289
  _globals['_TESTALLTYPES_MAPUINT64INT64WRAPPERENTRY']._serialized_start=29291
  _globals['_TESTALLTYPES_MAPUINT64INT64WRAPPERENTRY']._serialized_end=29380
  _globals['_TESTALLTYPES_MAPUINT64INT32WRAPPERENTRY']._serialized_start=29382
  _globals['_TESTALLTYPES_MAPUINT64INT32WRAPPERENTRY']._serialized_end=29471
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEWRAPPERENTRY']._serialized_start=29473
  _globals['_TESTALLTYPES_MAPUINT64DOUBLEWRAPPERENTRY']._serialized_end=29564
  _globals['_TESTALLTYPES_MAPUINT64FLOATWRAPPERENTRY']._serialized_start=29566
  _globals['_TESTALLTYPES_MAPUINT64FLOATWRAPPERENTRY']._serialized_end=29655
  _globals['_TESTALLTYPES_MAPUINT64UINT64WRAPPERENTRY']._serialized_start=29657
  _globals['_TESTALLTYPES_MAPUINT64UINT64WRAPPERENTRY']._serialized_end=29748
  _globals['_TESTALLTYPES_MAPUINT64UINT32WRAPPERENTRY']._serialized_start=29750
  _globals['_TESTALLTYPES_MAPUINT64UINT32WRAPPERENTRY']._serialized_end=29841
  _globals['_TESTALLTYPES_MAPUINT64STRINGWRAPPERENTRY']._serialized_start=29843
  _globals['_TESTALLTYPES_MAPUINT64STRINGWRAPPERENTRY']._serialized_end=29934
  _globals['_TESTALLTYPES_MAPUINT64BOOLWRAPPERENTRY']._serialized_start=29936
  _globals['_TESTALLTYPES_MAPUINT64BOOLWRAPPERENTRY']._serialized_end=30023
  _globals['_TESTALLTYPES_MAPUINT64BYTESWRAPPERENTRY']._serialized_start=30025
  _globals['_TESTALLTYPES_MAPUINT64BYTESWRAPPERENTRY']._serialized_end=30114
  _globals['_TESTALLTYPES_MAPSTRINGBOOLENTRY']._serialized_start=30116
  _globals['_TESTALLTYPES_MAPSTRINGBOOLENTRY']._serialized_end=30168
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGENTRY']._serialized_start=30170
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGENTRY']._serialized_end=30224
  _globals['_TESTALLTYPES_MAPSTRINGBYTESENTRY']._serialized_start=30226
  _globals['_TESTALLTYPES_MAPSTRINGBYTESENTRY']._serialized_end=30279
  _globals['_TESTALLTYPES_MAPSTRINGINT32ENTRY']._serialized_start=30281
  _globals['_TESTALLTYPES_MAPSTRINGINT32ENTRY']._serialized_end=30334
  _globals['_TESTALLTYPES_MAPSTRINGINT64ENTRY']._serialized_start=30336
  _globals['_TESTALLTYPES_MAPSTRINGINT64ENTRY']._serialized_end=30389
  _globals['_TESTALLTYPES_MAPSTRINGUINT32ENTRY']._serialized_start=30391
  _globals['_TESTALLTYPES_MAPSTRINGUINT32ENTRY']._serialized_end=30445
  _globals['_TESTALLTYPES_MAPSTRINGUINT64ENTRY']._serialized_start=30447
  _globals['_TESTALLTYPES_MAPSTRINGUINT64ENTRY']._serialized_end=30501
  _globals['_TESTALLTYPES_MAPSTRINGFLOATENTRY']._serialized_start=30503
  _globals['_TESTALLTYPES_MAPSTRINGFLOATENTRY']._serialized_end=30556
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEENTRY']._serialized_start=30558
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEENTRY']._serialized_end=30612
  _globals['_TESTALLTYPES_MAPSTRINGENUMENTRY']._serialized_start=30614
  _globals['_TESTALLTYPES_MAPSTRINGENUMENTRY']._serialized_end=30720
  _globals['_TESTALLTYPES_MAPSTRINGMESSAGEENTRY']._serialized_start=30722
  _globals['_TESTALLTYPES_MAPSTRINGMESSAGEENTRY']._serialized_end=30834
  _globals['_TESTALLTYPES_MAPSTRINGDURATIONENTRY']._serialized_start=30836
  _globals['_TESTALLTYPES_MAPSTRINGDURATIONENTRY']._serialized_end=30919
  _globals['_TESTALLTYPES_MAPSTRINGTIMESTAMPENTRY']._serialized_start=30921
  _globals['_TESTALLTYPES_MAPSTRINGTIMESTAMPENTRY']._serialized_end=31006
  _globals['_TESTALLTYPES_MAPSTRINGNULLVALUEENTRY']._serialized_start=31008
  _globals['_TESTALLTYPES_MAPSTRINGNULLVALUEENTRY']._serialized_end=31093
  _globals['_TESTALLTYPES_MAPSTRINGANYENTRY']._serialized_start=31095
  _globals['_TESTALLTYPES_MAPSTRINGANYENTRY']._serialized_end=31168
  _globals['_TESTALLTYPES_MAPSTRINGSTRUCTENTRY']._serialized_start=31170
  _globals['_TESTALLTYPES_MAPSTRINGSTRUCTENTRY']._serialized_end=31249
  _globals['_TESTALLTYPES_MAPSTRINGVALUEENTRY']._serialized_start=31251
  _globals['_TESTALLTYPES_MAPSTRINGVALUEENTRY']._serialized_end=31328
  _globals['_TESTALLTYPES_MAPSTRINGLISTVALUEENTRY']._serialized_start=31330
  _globals['_TESTALLTYPES_MAPSTRINGLISTVALUEENTRY']._serialized_end=31415
  _globals['_TESTALLTYPES_MAPSTRINGINT64WRAPPERENTRY']._serialized_start=31417
  _globals['_TESTALLTYPES_MAPSTRINGINT64WRAPPERENTRY']._serialized_end=31506
  _globals['_TESTALLTYPES_MAPSTRINGINT32WRAPPERENTRY']._serialized_start=31508
  _globals['_TESTALLTYPES_MAPSTRINGINT32WRAPPERENTRY']._serialized_end=31597
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEWRAPPERENTRY']._serialized_start=31599
  _globals['_TESTALLTYPES_MAPSTRINGDOUBLEWRAPPERENTRY']._serialized_end=31690
  _globals['_TESTALLTYPES_MAPSTRINGFLOATWRAPPERENTRY']._serialized_start=31692
  _globals['_TESTALLTYPES_MAPSTRINGFLOATWRAPPERENTRY']._serialized_end=31781
  _globals['_TESTALLTYPES_MAPSTRINGUINT64WRAPPERENTRY']._serialized_start=31783
  _globals['_TESTALLTYPES_MAPSTRINGUINT64WRAPPERENTRY']._serialized_end=31874
  _globals['_TESTALLTYPES_MAPSTRINGUINT32WRAPPERENTRY']._serialized_start=31876
  _globals['_TESTALLTYPES_MAPSTRINGUINT32WRAPPERENTRY']._serialized_end=31967
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGWRAPPERENTRY']._serialized_start=31969
  _globals['_TESTALLTYPES_MAPSTRINGSTRINGWRAPPERENTRY']._serialized_end=32060
  _globals['_TESTALLTYPES_MAPSTRINGBOOLWRAPPERENTRY']._serialized_start=32062
  _globals['_TESTALLTYPES_MAPSTRINGBOOLWRAPPERENTRY']._serialized_end=32149
  _globals['_TESTALLTYPES_MAPSTRINGBYTESWRAPPERENTRY']._serialized_start=32151
  _globals['_TESTALLTYPES_MAPSTRINGBYTESWRAPPERENTRY']._serialized_end=32240
  _globals['_TESTALLTYPES_NESTEDGROUP']._serialized_start=32242
  _globals['_TESTALLTYPES_NESTEDGROUP']._serialized_end=32297
  _globals['_TESTALLTYPES_NESTEDENUM']._serialized_start=32299
  _globals['_TESTALLTYPES_NESTEDENUM']._serialized_end=32338
  _globals['_NESTEDTESTALLTYPES']._serialized_start=32375
  _globals['_NESTEDTESTALLTYPES']._serialized_end=32519
  _globals['_TESTREQUIRED']._serialized_start=32521
  _globals['_TESTREQUIRED']._serialized_end=32559
# @@protoc_insertion_point(module_scope)
